@@ -16,6 +16,7 @@
 #' that are excluded with `FilterFindCorrelation` at score 0.1 (= 1 - 0.9).
 #'
 #' @family Filter
+#' @include Filter.R
 #' @template seealso_filter
 #' @export
 #' @examples
@@ -55,7 +56,7 @@ FilterFindCorrelation = R6Class("FilterFindCorrelation",
 
       super$initialize(
         id = "find_correlation",
-        task_types = c("classif", "regr"),
+        task_types = NA_character_,
         param_set = param_set,
         feature_types = c("integer", "numeric"),
         packages = "stats",
@@ -93,6 +94,14 @@ FilterFindCorrelation = R6Class("FilterFindCorrelation",
       # The following has the correct names and values, BUT we need scores in
       # reverse order. Shift by 1 to get positive values.
       1 - apply(cm, 2, max)
+    },
+    .get_properties = function() {
+      use = self$param_set$values$use %??% "everything"
+      if (use %in% c("complete.obs", "pairwise.complete.obs")) {
+        "missings"
+      } else {
+        character(0)
+      }
     }
   )
 )
