@@ -1,4 +1,6 @@
-test_that("FilterImportance", {
+skip_if_not_installed("caret")
+
+test_that("FilterFindCorrelation", {
   task = mlr3::mlr_tasks$get("sonar")
   equalcor = cbind(
     a = rep(c(1, 0, 0, 0), task$nrow / 4), b = c(0, 1, 0, 0),
